pub enum ExecuteMsg {
Deposit {},
Withdraw {
amount: Uint128,
},
Claim {},
SetAdmin {
admin: Option<String>,
pause_admin: Option<String>,
},
SetContractState {
state: bool,
},
}Variants
Deposit
Moves native tokens sent along the message to the instant unstaking liquidity pool, and gives back loop shares to the sender to represent his liquidity.
Withdraw
Withdraw ARCH from the instant unstaking liquidity pool by putting the representive loop shares amount in the param.
Claim
Gives sender his claimable withdrawn native token, should be called after sender’s withdrawing request is processed.
SetAdmin
Updates admin’s addresses, only the admin can call this.
SetContractState
Updates contract state, only the pause admin can call this.