pub struct WithdrawingQueueResponse {
pub state: LinkedList,
pub queue: Vec<NodeWithId>,
}Fields
state: LinkedListqueue: Vec<NodeWithId>Trait Implementations
Sourceimpl Clone for WithdrawingQueueResponse
impl Clone for WithdrawingQueueResponse
Sourcefn clone(&self) -> WithdrawingQueueResponse
fn clone(&self) -> WithdrawingQueueResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WithdrawingQueueResponse
impl Debug for WithdrawingQueueResponse
Sourceimpl<'de> Deserialize<'de> for WithdrawingQueueResponse
impl<'de> Deserialize<'de> for WithdrawingQueueResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WithdrawingQueueResponse
impl JsonSchema for WithdrawingQueueResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for WithdrawingQueueResponse
impl PartialEq for WithdrawingQueueResponse
Sourcefn eq(&self, other: &WithdrawingQueueResponse) -> bool
fn eq(&self, other: &WithdrawingQueueResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WithdrawingQueueResponse
impl Serialize for WithdrawingQueueResponse
impl StructuralPartialEq for WithdrawingQueueResponse