ExecuteMsg

Enum ExecuteMsg 

pub enum ExecuteMsg {
Show 13 variants Stake { to: Option<String>, }, Claim {}, SetAdmin { admin: Option<String>, pause_admin: Option<String>, }, SetContractState { state: bool, }, SetLiquidToken { address: String, }, SetRewardsConfig { swap_contract_addr: Option<String>, treasury_contract_addr: Option<String>, team_wallet_addr: Option<String>, commission_percentage: Option<u16>, team_percentage: Option<u16>, liquidity_percentage: Option<u16>, }, SetLimitConfig { maximum_processed: Option<Uint128>, processed_time: Option<u64>, unstaking_time: Option<u64>, mint_cap: Option<Uint128>, }, SetDelegations { delegations: Vec<DelegationPercentage>, }, BondUnbondValidators {}, ProcessUnstakingQueue {}, DistributeRewards {}, BotRoutine {}, Receive(Cw20ReceiveMsg),
}

Variants



Stake

Moves native tokens sent along the message to the staking pool, and gives back liquid tokens to the sender (or to the address sender put into the optional to param).

Fields



Claim

Gives sender his claimable unstaked native token, should be called after sender’s unstaking request is processed.



SetAdmin

Updates admin’s addresses, only the admin can call this.

Fields

pause_admin: Option<String>


SetContractState

Updates contract state, only the pause admin can call this.

Fields

state: bool


SetLiquidToken

Set the liquid token address, only the admin can call this. This can only be called once after deploying the liquid token contract.

Fields

address: String


SetRewardsConfig

Update the configs relate to the incentives handling of staking rewards, only the admin can call this.

Fields

swap_contract_addr: Option<String>
treasury_contract_addr: Option<String>
team_wallet_addr: Option<String>
commission_percentage: Option<u16>
team_percentage: Option<u16>
liquidity_percentage: Option<u16>


SetLimitConfig

Update the limits in process unstaking requests, only the admin can call this.

Fields

maximum_processed: Option<Uint128>
processed_time: Option<u64>
unstaking_time: Option<u64>
mint_cap: Option<Uint128>


SetDelegations

Update the validators whitelist, only the admin can call this.

Fields



BondUnbondValidators

bond available coin or unbond to process unstaking requests



ProcessUnstakingQueue

use available coin to process unstaking requests



DistributeRewards

bot or users call this to distribute staking rewards



BotRoutine

bot or users call this daily to multicall the following: DistributeRewards, ProcessUnstakingQueue, BondUnbondValidators



Receive(Cw20ReceiveMsg)

handle Send messages from cw20 token contract, only the liquid token contract can call this. This is for the unstaking process.