pub struct LimitResponse {
pub maximum_processed: Uint128,
pub current_processed: Uint128,
pub processed_time: u64,
pub processed_period: Expiration,
pub unstaking_time: u64,
pub unstaking_period: Expiration,
pub mint_cap: Uint128,
}Fields
maximum_processed: Uint128current max unstake processing amount allowed in the period
current_processed: Uint128processed_time: u64processed_period: Expirationunstaking_time: u64the minimum number of blocks between each contract unstaking request
unstaking_period: Expirationcontract can only call unbound after this period
mint_cap: Uint128current max amount of liquid token can be minted