pub struct StatusResponse {
pub issued: Uint128,
pub native: Coin,
pub unstakings: Uint128,
pub claims: Uint128,
pub bonded: Uint128,
pub balance: Uint128,
pub ratio: Decimal,
}Fields
issued: Uint128issued is how many derivative tokens this contract has issued
native: Coinnative is how many total supply of native tokens liquid token holders can withdraw
unstakings: Uint128unstakings is how many total native tokens in unstaking queue
claims: Uint128claims is how many tokens need to be reserved paying back those who unbonded
bonded: Uint128bonded is how many native tokens exist bonded to the validator
balance: Uint128available native token balance of this contract
ratio: Decimalratio of native / issued (or how many native tokens that one derivative token is nominally worth)