pub struct UnstakingQueueResponse {
pub state: LinkedList,
pub queue: Vec<NodeWithId>,
}Fields
state: LinkedListqueue: Vec<NodeWithId>Trait Implementations
Sourceimpl Clone for UnstakingQueueResponse
impl Clone for UnstakingQueueResponse
Sourcefn clone(&self) -> UnstakingQueueResponse
fn clone(&self) -> UnstakingQueueResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnstakingQueueResponse
impl Debug for UnstakingQueueResponse
Sourceimpl<'de> Deserialize<'de> for UnstakingQueueResponse
impl<'de> Deserialize<'de> for UnstakingQueueResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UnstakingQueueResponse
impl JsonSchema for UnstakingQueueResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UnstakingQueueResponse
impl PartialEq for UnstakingQueueResponse
Sourcefn eq(&self, other: &UnstakingQueueResponse) -> bool
fn eq(&self, other: &UnstakingQueueResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UnstakingQueueResponse
impl Serialize for UnstakingQueueResponse
impl StructuralPartialEq for UnstakingQueueResponse