pub struct NodeWithId {
pub id: u64,
pub info: Node,
}Fields
id: u64info: NodeTrait Implementations
Sourceimpl Clone for NodeWithId
impl Clone for NodeWithId
Sourcefn clone(&self) -> NodeWithId
fn clone(&self) -> NodeWithId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeWithId
impl Debug for NodeWithId
Sourceimpl<'de> Deserialize<'de> for NodeWithId
impl<'de> Deserialize<'de> for NodeWithId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NodeWithId
impl JsonSchema for NodeWithId
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NodeWithId
impl PartialEq for NodeWithId
Sourcefn eq(&self, other: &NodeWithId) -> bool
fn eq(&self, other: &NodeWithId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NodeWithId
impl Serialize for NodeWithId
impl StructuralPartialEq for NodeWithId