pub enum QueryMsg {
ClaimableOf {
address: String,
},
ConfigInfo {},
StatusInfo {},
OrderBook {},
OrderInfoOf {
address: String,
},
Simulation {
offer_asset: Asset,
},
ReverseSimulation {
ask_asset: Asset,
},
}Variants
ClaimableOf
Returns the claimable swapped liquid token and native token rewards the address can claim.
ConfigInfo
Returns the configuration of the contract.
StatusInfo
Returns the staking status of the contract.
OrderBook
Returns the first 50 orders in the liquidity queue.
OrderInfoOf
Returns the order info of the address in the liquidity queue.
Simulation
Return the amount of native token swapper should get.
ReverseSimulation
Return the amount of liquid token swapper should put in to get an ask_asset amount of native token.